// xml_get_attribute - return the specified attribute from the specified element


// Copyright  2006 by Jef Poskanzer <jef@mail.acme.com>.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions
// are met:
// 1. Redistributions of source code must retain the above copyright
//    notice, this list of conditions and the following disclaimer.
// 2. Redistributions in binary form must reproduce the above copyright
//    notice, this list of conditions and the following disclaimer in the
//    documentation and/or other materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
// OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
// HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
// LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
// OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
// SUCH DAMAGE.
//
// For commentary on this license please see http://www.acme.com/license.html


#include <fstream>

#include "XmlParser.h"


int main( int argc, char* argv[] )
    {
    if ( argc < 3 )
	{
	std::cerr << "usage: " << argv[0] << " element attribute ...\n";
	exit( 1 );
	}
    std::string elementName = argv[1];
    typedef std::vector<std::string> StrVec;
    StrVec attributeNames;
    for ( int argn = 2; argn < argc; ++argn )
	attributeNames.push_back( argv[argn] );

    try {
	XIP* xp = new XmlParser( &std::cin );
	int prevId = -1;
	while ( xp->hasMoreText() )
	    {
	    const XipText& xt = xp->getNextText();
	    for ( XipElementVec::const_iterator i = xt.elements.begin(); i != xt.elements.end(); ++i )
		{
		if ( i->name == elementName && i->id != prevId )
		    {
		    prevId = i->id;
		    bool bol = true;
		    for ( StrVec::const_iterator j = attributeNames.begin(); j != attributeNames.end(); ++j )
			{
			XipAttributes::const_iterator k = i->attributes.find( *j );
			if ( k != i->attributes.end() )
			    {
			    if ( bol )
				bol = false;
			    else
				std::cout << " ";
			    std::cout << k->second;
			    }
			}
		    std::cout << "\n";
		    }
		}
	    }
	delete xp;
	}
    catch ( XipException e )
	{
	std::cerr << e.reason << " at line " << e.line << "\n";
	exit( 1 );
	}

    exit( 0 );
    }
